==> actions-recorder-0.0.10.tgz: package/lib/app/todolist.js <==
var Immutable, React, actions, classnames, div, input, onAdd, rendeTask, render;

React = require("react");

Immutable = require("immutable");

classnames = require("classnames");

actions = require("../actions");

div = React.createFactory("div");

input = React.createFactory("input");

module.exports = React.createClass({
  displayName: "app-todolist",
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.List)
  },
  onAdd: onAdd = function() {
    return actions.add();
  },
  rendeTask: rendeTask = function(task) {
    var checkboxClassName, onRemove, onToggle, onUpdate;
    onToggle = onToggle = function() {
      return actions.toggle(task.get("id"));
    };
    onUpdate = onUpdate = function(event) {
      return actions.update(task.get("id"), event.target.value);
    };
    onRemove = onRemove = function() {
      return actions.remove(task.get("id"));
    };
    checkboxClassName = classnames("checkbox", {
      "is-checked": task.get("done")
    });
    return div({
      className: "todolist-task line",
      key: task.get("id")
    }, div({
      className: checkboxClassName,
      onClick: onToggle
    }), input({
      type: "text",
      value: task.get("text"),
      onChange: onUpdate
    }), div({
      className: "button is-danger",
      onClick: onRemove
    }, "Remove"));
  },
  render: render = function() {
    return div({
      className: "app-todolist"
    }, div({
      className: "todolist-header"
    }, div({
      className: "button is-attract",
      onClick: this.onAdd
    }, "Add")), div({
      className: "todolist-table"
    }, this.props.store.map(this.rendeTask)));
  }
});

==> actions-recorder-1.1.2.tgz: package/lib/app/todolist.js <==
var Immutable, React, a, actions, classnames, div, input, onAdd, ref, rendeTask, render, repo;

React = require("react");

Immutable = require("immutable");

classnames = require("classnames");

actions = require("../actions");

ref = React.DOM, div = ref.div, a = ref.a, input = ref.input;

repo = 'https://github.com/teambition/actions-recorder';

module.exports = React.createClass({
  displayName: "app-todolist",
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.List)
  },
  onAdd: onAdd = function() {
    return actions.add();
  },
  rendeTask: rendeTask = function(task) {
    var checkboxClassName, onRemove, onToggle, onUpdate;
    onToggle = onToggle = function() {
      return actions.toggle(task.get("id"));
    };
    onUpdate = onUpdate = function(event) {
      return actions.update(task.get("id"), event.target.value);
    };
    onRemove = onRemove = function() {
      return actions.remove(task.get("id"));
    };
    checkboxClassName = classnames("checkbox", {
      "is-checked": task.get("done")
    });
    return div({
      className: "todolist-task line",
      key: task.get("id")
    }, div({
      className: checkboxClassName,
      onClick: onToggle
    }), input({
      type: "text",
      value: task.get("text"),
      onChange: onUpdate
    }), div({
      className: "button is-danger",
      onClick: onRemove
    }, "Remove"));
  },
  renderNote: function() {
    return div({
      className: 'note'
    }, a({
      href: repo
    }, "Demo of actions-recorder, find more on GitHub."));
  },
  render: render = function() {
    return div({
      className: "app-todolist"
    }, this.renderNote(), div({
      className: "todolist-table"
    }, this.props.store.map(this.rendeTask)), div({
      className: "todolist-footer"
    }, div({
      className: "button is-attract",
      onClick: this.onAdd
    }, "Add")));
  }
});
